ISMtools-package: ISMtools: Interpretive Structural Modelling Analysis Tools

ISMtools-packageR Documentation

ISMtools: Interpretive Structural Modelling Analysis Tools

Description

A comprehensive toolkit for Interpretive Structural Modelling (ISM) and MICMAC analysis. ISM is a methodology for identifying and summarizing relationships among specific elements which define an issue or problem.

Input Functions

create_relation_matrix

Create or convert adjacency matrices

convert_to_matrix

Convert edge lists to adjacency matrices

create_ssim

Create SSIM (Structural Self-Interaction Matrix) template

ssim_to_matrix

Convert SSIM (V/A/X/O) to adjacency matrix

Core Analysis Functions

compute_reachability

Calculate reachability matrix using Warshall's algorithm

level_partitioning

Perform hierarchical level decomposition

micmac_analysis

MICMAC analysis (driving/dependence power)

extract_direct_edges

Transitive reduction for clean diagrams

Visualization Functions

plot_ism

Static ISM structure visualization (base R or igraph)

plot_interactive_ism

Interactive ISM visualization (requires visNetwork)

plot_micmac

MICMAC scatter plot

Typical Workflow

  1. Create SSIM using create_ssim or adjacency matrix using create_relation_matrix

  2. Convert SSIM to adjacency matrix using ssim_to_matrix (if applicable)

  3. Compute reachability matrix using compute_reachability

  4. Perform level partitioning using level_partitioning

  5. Perform MICMAC analysis using micmac_analysis

  6. Visualize results using plot_ism and plot_micmac

Example Data

The package includes an example dataset ism_example containing a project risk factors adjacency matrix for demonstration purposes.

Author(s)

Maintainer: Yi Tang tangyi@cidp.edu.cn (ORCID)

References

Warfield, J. N. (1974). Developing interconnection matrices in structural modeling. IEEE Transactions on Systems, Man, and Cybernetics, SMC-4(1), 81-87. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1109/TSMC.1974.5408524")}

Sage, A. P. (1977). Interpretive Structural Modeling: Methodology for Large-scale Systems. McGraw-Hill.


ISMtools documentation built on March 13, 2026, 1:06 a.m.